# teambition-oapi-sdk
Teambition Open API

## 环境要求

Python 3.9+

## 安装与使用
### pip 安装

如果 Python 软件包托管在代码仓库中，可以直接使用以下命令安装：

```sh
pip install git+https://github.com/teambition-devcenter/openapi-sdk-python.git
```
（可能需要使用管理员权限运行：`sudo pip install git+https://github.com/teambition-devcenter/openapi-sdk-python.git`）

然后导入软件包：
```python
import teambition_oapi_sdk
```

### Setuptools 安装

通过 [Setuptools](http://pypi.python.org/pypi/setuptools) 安装。

```sh
python setup.py install --user
```
（或使用 `sudo python setup.py install` 为所有用户安装）

然后导入软件包：
```python
import teambition_oapi_sdk
```

### 测试

执行 `pytest` 命令运行测试。

## 快速开始

请先按照上述[安装步骤](#安装与使用)进行操作，然后运行以下代码：

### 使用示例：check_user_visible_in_app

```python
import time
import teambition_oapi_sdk
from teambition_oapi_sdk.api import app_api
from teambition_oapi_sdk.model import CheckUserVisibleInAppRequest
from pprint import pprint

# Defining the host is optional and defaults to https://open.teambition.com
# See configuration.py for a list of all supported configuration parameters.
configuration = teambition_oapi_sdk.Configuration(
    host = "https://open.teambition.com",
    app_id = "{{AppId}}",
    app_secret = "{{AppSecret}}"
)

# Enter a context with an instance of the API client
with teambition_oapi_sdk.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = app_api.AppApi(api_client)

    x_tenant_id = "{{x_tenant_id}}"  # 企业 ID
    check_user_visible_in_app_request = CheckUserVisibleInAppRequest()

    try:
        # 批量查询用户应用可见性
        api_response = api_instance.check_user_visible_in_app(x_tenant_id, check_user_visible_in_app_request)
        pprint(api_response)
    except Exception as e:
        print("Exception when calling AppApi->check_user_visible_in_app: %s\n" % e)

```

### API 接口文档

所有 URI 都相对于 *https://open.teambition.com/api*

类名 | 方法 | HTTP 请求 | 描述
------------ | ------------- | ------------- | -------------
*AppApi* | [**check_user_visible_in_app**](https://open.teambition.com/docs/apis/6321c6cd912d20d3b5a4884b) | **POST** /user/app/exists | 批量查询用户应用可见性
*AppApi* | [**get_app_access_token**](https://open.teambition.com/docs/apis/6687ac14c35daba54d25e578) | **POST** /appToken | 获取应用授权Token
*AutoflowApi* | [**trigger_custom_event**](https://open.teambition.com/docs/apis/6527b37e912d20d3b57881d3) | **POST** /autoflow/custom-event/trigger | 触发自动化自定义事件
*CodeApi* | [**create_platform**](https://open.teambition.com/docs/apis/642699d77a073e002ba6fa26) | **POST** /code/pipeline/platforms | 创建流水线源平台
*CodeApi* | [**get_pipeline**](https://open.teambition.com/docs/apis/63f868a65e4331002ae93af8) | **GET** /code/pipeline/get/{platformId} | 根据code查询流水线
*CodeApi* | [**get_pipeline_platform**](https://open.teambition.com/docs/apis/63f826f54493a7002b2b459e) | **GET** /code/platform/get | 根据名称查询流水线源平台
*CodeApi* | [**get_platforms**](https://open.teambition.com/docs/apis/642697f07a073e002ba6f4b9) | **GET** /code/pipeline/platforms | 查询流水线源平台
*CodeApi* | [**sync_builds**](https://open.teambition.com/docs/apis/64269d517a073e002ba703e2) | **POST** /code/pipeline/platforms/{platformId}/pipelines/{pipelineId}/builds | 同步构建信息
*CodeApi* | [**sync_pipelines**](https://open.teambition.com/docs/apis/64269bdd7a073e002ba6fdf0) | **POST** /code/pipeline/platforms/{platformId}/pipelines | 同步流水线信息
*CodeApi* | [**update_pipeline_params**](https://open.teambition.com/docs/apis/63f865b05e4331002ae92888) | **POST** /code/pipeline/platforms/{platformId}/pipelines/{pipelineId}/buildParams | 同步流水线构建参数信息
*CodeApi* | [**update_pipeline_platform**](https://open.teambition.com/docs/apis/63f822db4493a7002b2b384f) | **POST** /code/platform/update/{platformId} | 更新流水线源平台
*ContactApi* | [**add_department_members**](https://open.teambition.com/docs/apis/667d5158912d20d3b5b76029) | **POST** /org/department/members | 添加部门成员
*ContactApi* | [**batch_get_org_members**](https://open.teambition.com/docs/apis/6321c6ce912d20d3b5a48b59) | **POST** /org/member/batchGet | 批量获取企业成员
*ContactApi* | [**count_org_members**](https://open.teambition.com/docs/apis/6321c6ce912d20d3b5a48b29) | **GET** /org/member/count | 获取企业成员数量
*ContactApi* | [**create_department**](https://open.teambition.com/docs/apis/632828c3912d20d3b5aca5ab) | **POST** /org/department/create | 创建部门
*ContactApi* | [**create_org_role**](https://open.teambition.com/docs/apis/67d275d8713c85f499e9437c) | **POST** /org/organizations/{organizationId}/role/create | 创建企业角色
*ContactApi* | [**delete_department**](https://open.teambition.com/docs/apis/632828c3912d20d3b5aca62a) | **DELETE** /org/department/delete | 删除部门
*ContactApi* | [**delete_org_member**](https://open.teambition.com/docs/apis/6321c6ce912d20d3b5a48afb) | **POST** /org/member/delete | 删除企业成员
*ContactApi* | [**disable_org_member**](https://open.teambition.com/docs/apis/6321c6ce912d20d3b5a48abe) | **POST** /org/member/disable | 停用企业成员账号
*ContactApi* | [**enable_org_member**](https://open.teambition.com/docs/apis/6321c6ce912d20d3b5a48a8e) | **POST** /org/member/enable | 启用企业成员账号
*ContactApi* | [**get_department**](https://open.teambition.com/docs/apis/632828c3912d20d3b5aca571) | **GET** /org/department/info | 获取部门详情
*ContactApi* | [**get_role_info**](https://open.teambition.com/docs/apis/64d34c89912d20d3b54f029c) | **GET** /org/role/info | 获取角色详情
*ContactApi* | [**list_department_members**](https://open.teambition.com/docs/apis/6321c6ce912d20d3b5a48bfc) | **GET** /org/department/members | 获取部门成员列表
*ContactApi* | [**list_departments**](https://open.teambition.com/docs/apis/6321c6ce912d20d3b5a48bbc) | **GET** /org/departments | 获取企业部门列表
*ContactApi* | [**list_org_admins**](https://open.teambition.com/docs/apis/6321c6ce912d20d3b5a48974) | **GET** /org/admins | 获取企业的管理员（含拥有者）
*ContactApi* | [**list_org_members**](https://open.teambition.com/docs/apis/6321c6ce912d20d3b5a489ee) | **GET** /org/member/list | 获取企业成员列表
*ContactApi* | [**list_org_owners**](https://open.teambition.com/docs/apis/6321c6ce912d20d3b5a489be) | **GET** /org/owners | 获取企业拥有者
*ContactApi* | [**list_org_roles**](https://open.teambition.com/docs/apis/64d34c89912d20d3b54f0373) | **GET** /org/roles | 获取企业角色列表
*ContactApi* | [**list_sub_departments**](https://open.teambition.com/docs/apis/667d5158912d20d3b5b75f43) | **GET** /org/departments/subDepts | 获取子部门列表
*ContactApi* | [**list_user_departments**](https://open.teambition.com/docs/apis/6321c6ce912d20d3b5a48c30) | **GET** /user/joinedDepartments | 获取用户加入的企业部门列表
*ContactApi* | [**remove_department_members**](https://open.teambition.com/docs/apis/667d5159912d20d3b5b76087) | **DELETE** /org/department/members | 删除部门成员
*ContactApi* | [**resign_org_member**](https://open.teambition.com/docs/apis/681b514d8657139bff2fe828) | **POST** /org/member/resignation | 离职企业成员账号
*ContactApi* | [**search_org_members**](https://open.teambition.com/docs/apis/6321c6ce912d20d3b5a48b88) | **GET** /org/member/search | 搜索企业成员
*ContactApi* | [**update_department**](https://open.teambition.com/docs/apis/632828c3912d20d3b5aca5ed) | **PUT** /org/department/update | 更新部门信息
*ContactApi* | [**update_org_member**](https://open.teambition.com/docs/apis/6321c6ce912d20d3b5a48a5b) | **PUT** /org/member/update | 更新企业成员
*CustomfieldApi* | [**count_by_category_v3**](https://open.teambition.com/docs/apis/63ee3ea2912d20d3b543ee9c) | **GET** /v3/customfield/count-by-category | 根据自定义字段分类统计自定义字段数
*CustomfieldApi* | [**create_project_customfield_v3**](https://open.teambition.com/docs/apis/6321c6d0912d20d3b5a492ca) | **POST** /v3/customfield/create | 创建项目自定义字段(提交项目ID),创建企业自定义字段
*CustomfieldApi* | [**delete_customfield_v3**](https://open.teambition.com/docs/apis/6321c6d0912d20d3b5a4930c) | **POST** /v3/customfield/{customfieldId}/delete | 删除自定义字段，默认删除企业自定义字段，如果传递项目ID，则删除项目下自定义字段
*CustomfieldApi* | [**search_field_categories_v3**](https://open.teambition.com/docs/apis/63ee3ea2912d20d3b543ee57) | **GET** /v3/customfield-category/search | 搜索企业自定义字段分类
*CustomfieldApi* | [**search_field_choices_v3**](https://open.teambition.com/docs/apis/64057c9b912d20d3b5e63df6) | **GET** /v3/customfield/{customfieldId}/choice/search | 搜索层级字段选项
*CustomfieldApi* | [**search_org_customfiled_v3**](https://open.teambition.com/docs/apis/6321c6d0912d20d3b5a49355) | **GET** /v3/customfield/search | 搜索企业自定义字段
*CustomfieldApi* | [**update_customfield_v3**](https://open.teambition.com/docs/apis/6321c6d0912d20d3b5a49391) | **PUT** /v3/customfield/{customfieldId}/update | 更新自定义字段，默认更新企业自定义字段，如果传递项目ID，则更新项目下自定义字段
*CustomfieldApi* | [**update_field_choices_v3**](https://open.teambition.com/docs/apis/64057c9b912d20d3b5e63e6c) | **POST** /v3/customfield/{customfieldId}/choice/update | 更新层级字段选项
*DingGroupApi* | [**bind_project_group**](https://open.teambition.com/docs/apis/65f95b1bdfa703a68f96c05e) | **POST** /group/bindProject | 项目关联绑定钉钉群聊
*DingGroupApi* | [**get_binding_cid_by_task_id**](https://open.teambition.com/docs/apis/664c9212e678cdcec87811ba) | **GET** /group/getBindingCidByTaskId | 通过taskId查询该任务关联的任务群Id
*DingGroupApi* | [**get_binding_cids_by_project_id**](https://open.teambition.com/docs/apis/6378b1e6912d20d3b517bea6) | **GET** /group/getBindingCidsByProjectId | 通过projectid查询关联的全员可见的群聊ids
*DingGroupApi* | [**get_binding_project_ids_by_cid**](https://open.teambition.com/docs/apis/6378b1e6912d20d3b517bf09) | **GET** /group/getBindingProjectIdsByCid | 根据群聊cid获取绑定的项目projectid
*DingtalkApi* | [**bind_project_workspace**](https://open.teambition.com/docs/apis/65af6cec2442f01adbdedec9) | **POST** /workspace/bind-project | 绑定已有知识库
*DingtalkApi* | [**get_task_ids_by_approve_id**](https://open.teambition.com/docs/apis/64f5d782a96085002bab6976) | **GET** /approve/getTaskIdsByInstanceId | 通过钉钉审批实例ID反查对应任务IDs
*DingtalkApi* | [**get_workspace_info**](https://open.teambition.com/docs/apis/66b9c71e68fd651bec0a05d3) | **GET** /workspace/query | 获取绑定知识库信息
*FavoritesApi* | [**get_v3_favorite_list**](https://open.teambition.com/docs/apis/68da36dd92244c2db35778a9) | **GET** /v3/favorite/list | 获取收藏夹关联的主体ID
*FileApi* | [**batch_get_file_details**](https://open.teambition.com/docs/apis/65b20e66912d20d3b5781196) | **POST** /v3/file/query/by-resource-ids | 根据 resourceId 批量获取文件详情
*FileApi* | [**create_file_v3**](https://open.teambition.com/docs/apis/6411504e912d20d3b56ec570) | **POST** /v3/work/create | 创建文件库文件
*FileApi* | [**create_folder_v3**](https://open.teambition.com/docs/apis/64db2903912d20d3b5bb0034) | **POST** /v3/collection/create | 创建文件夹
*FileApi* | [**create_upload_token_v3**](https://open.teambition.com/docs/apis/64114f70912d20d3b56e0c59) | **POST** /v3/awos/upload-token | 创建文件上传凭证
*FileApi* | [**get_file_detail_v3**](https://open.teambition.com/docs/apis/64db2921912d20d3b5bb5250) | **GET** /v3/work/query | 获取项目文件详情
*FileApi* | [**get_file_token**](https://open.teambition.com/docs/apis/65810e45912d20d3b5887d1b) | **POST** /v3/file/file-token | 从现有文件资源创建 fileToken，可用于创建其他文件资源
*FileApi* | [**get_folder_detail_v3**](https://open.teambition.com/docs/apis/64db2903912d20d3b5bb021f) | **GET** /v3/collection/query | 获取文件夹详情
*FileApi* | [**get_v3_work_activity_query**](https://open.teambition.com/docs/apis/688c2ab5912d20d3b5bd730f) | **GET** /v3/work/{workId}/activity/list | 获取文件动态
*FileApi* | [**get_v3_work_version_query**](https://open.teambition.com/docs/apis/688c2ab5912d20d3b5bd75f9) | **GET** /v3/work/{workId}/version/query | 获取文件所有版本
*FileApi* | [**list_files_v3**](https://open.teambition.com/docs/apis/6411504e912d20d3b56ec5ff) | **GET** /v3/work/list | 获取文件列表
*FileApi* | [**move_file_v3**](https://open.teambition.com/docs/apis/64db2930912d20d3b5bb7d96) | **POST** /v3/work/{workId}/parent | 项目内移动文件
*FileApi* | [**move_folder_v3**](https://open.teambition.com/docs/apis/64db2903912d20d3b5bb00c9) | **POST** /v3/collection/{collectionId}/parent | 移动文件夹
*FileApi* | [**post_v3_collection_archive**](https://open.teambition.com/docs/apis/688c2ab4912d20d3b5bd71b3) | **POST** /v3/collection/{collectionId}/archive | 文件夹移入回收站
*FileApi* | [**post_v3_collection_delete**](https://open.teambition.com/docs/apis/688c2ab4912d20d3b5bd7239) | **POST** /v3/collection/{collectionId}/delete | 删除文件夹
*FileApi* | [**post_v3_work_archive**](https://open.teambition.com/docs/apis/688c2ab5912d20d3b5bd737c) | **POST** /v3/work/{workId}/archive | 文件移入回收站
*FileApi* | [**post_v3_work_involvemember_update**](https://open.teambition.com/docs/apis/688c2ab5912d20d3b5bd74bf) | **POST** /v3/work/{workId}/involveMember/update | 修改文件参与者
*FileApi* | [**post_v3_work_main_set**](https://open.teambition.com/docs/apis/688c2ab5912d20d3b5bd751d) | **POST** /v3/work/{workId}/main-version/update | 设置文件主版本
*FileApi* | [**post_v3_work_visible_update**](https://open.teambition.com/docs/apis/688c2ab5912d20d3b5bd7652) | **POST** /v3/work/{workId}/visible/update | 修改文件可见性
*FileApi* | [**search_files_v3**](https://open.teambition.com/docs/apis/68510bf3912d20d3b5cd319e) | **GET** /v3/work/search | 深度搜索项目内的文件和文件夹
*FileApi* | [**update_file_name_v3**](https://open.teambition.com/docs/apis/64db2930912d20d3b5bb7d17) | **POST** /v3/work/{workId}/name/update | 更新文件标题
*FileApi* | [**update_file_version_v3**](https://open.teambition.com/docs/apis/64db2930912d20d3b5bb7e0e) | **POST** /v3/work/{workId}/version | 更新文件版本
*FileApi* | [**update_folder_title_v3**](https://open.teambition.com/docs/apis/64db2903912d20d3b5bb0173) | **POST** /v3/collection/{collectionId}/title/update | 更新文件夹标题
*FileApi* | [**update_folder_visibility**](https://open.teambition.com/docs/apis/676bb6ff912d20d3b56b8d0f) | **POST** /v3/collection/visible/update | 更新文件夹可见性
*FormApi* | [**create_form_record_v3**](https://open.teambition.com/docs/apis/680b630d912d20d3b51dcf46) | **POST** /v3/form/record/create | 创建表单记录
*FormApi* | [**get_form_project_space_link_v3**](https://open.teambition.com/docs/apis/680b630e912d20d3b51dd06d) | **GET** /v3/form/project/link | 根据项目ID获取表单空间或根据表单空间ID获取项目ID
*FormApi* | [**list_all_form_space_nodes_v3**](https://open.teambition.com/docs/apis/680b630e912d20d3b51dd0c4) | **GET** /v3/form/node/list | 获取表单空间节点列表
*FormApi* | [**search_form_record_process_nodes_v3**](https://open.teambition.com/docs/apis/6808506d912d20d3b5bfe326) | **GET** /v3/form/record/{recordId}/process/instance/node/search | 获取表单记录流程节点信息
*FormApi* | [**update_form_record_field_v3**](https://open.teambition.com/docs/apis/680b630e912d20d3b51dd01c) | **POST** /v3/form/record/{recordId}/update | 更新表单字段值
*GanttApi* | [**create_baseline**](https://open.teambition.com/docs/apis/66b4ae32912d20d3b58405f5) | **POST** /v3/gantt/baseline | 项目下创建甘特图基线
*GanttApi* | [**get_baseline_tasks_v3**](https://open.teambition.com/docs/apis/6424f857912d20d3b50b048a) | **GET** /v3/gantt/baseline-task | 获取甘特图基线下的任务
*GanttApi* | [**get_baselines_v3**](https://open.teambition.com/docs/apis/6424f885912d20d3b50b759b) | **GET** /v3/gantt/baseline | 获取项目下甘特图基线
*GanttApi* | [**update_baseline**](https://open.teambition.com/docs/apis/66d98080253a3f2062f9b838) | **PUT** /v3/gantt/baseline | 更新项目下甘特图基线
*GroupApi* | [**add_group_member**](https://open.teambition.com/docs/apis/64d34cb2912d20d3b54f6e39) | **POST** /org/group/member/add | 添加群组成员
*GroupApi* | [**batch_get_group_members**](https://open.teambition.com/docs/apis/64d34cb2912d20d3b54f6dba) | **POST** /org/group/member/batchGet | 批量获取群组成员
*GroupApi* | [**batch_get_groups**](https://open.teambition.com/docs/apis/64d44dbe912d20d3b53a8340) | **POST** /org/group/batchGet | 批量获取群组信息
*GroupApi* | [**create_group**](https://open.teambition.com/docs/apis/64d34c9c912d20d3b54f33ea) | **POST** /org/group/create | 创建群组
*GroupApi* | [**delete_group**](https://open.teambition.com/docs/apis/64d34c9c912d20d3b54f34ee) | **DELETE** /org/group/delete | 删除群组
*GroupApi* | [**list_group_members**](https://open.teambition.com/docs/apis/64d34cb2912d20d3b54f6d10) | **GET** /org/group/members | 获取群组成员列表
*GroupApi* | [**remove_group_member**](https://open.teambition.com/docs/apis/64d34cb2912d20d3b54f6e8d) | **DELETE** /org/group/member/delete | 删除群组成员
*GroupApi* | [**search_groups**](https://open.teambition.com/docs/apis/64d34c9c912d20d3b54f3379) | **GET** /org/group/search | 搜索群组
*GroupApi* | [**update_group**](https://open.teambition.com/docs/apis/64d34c9c912d20d3b54f3487) | **PUT** /org/group/update | 更新群组
*OauthApi* | [**get_o_auth_user_info**](https://open.teambition.com/docs/apis/6321c6cd912d20d3b5a487e2) | **POST** /oauth/userInfo | 获取登录用户信息
*OauthApi* | [**get_sso_token**](https://open.teambition.com/docs/apis/6321c6cd912d20d3b5a48785) | **GET** /oauth/sso | 请求身份验证
*OauthApi* | [**get_user_access_token**](https://open.teambition.com/docs/apis/6321c6cd912d20d3b5a487bd) | **POST** /oauth/userAccessToken | 获取登录用户身份
*OrgApi* | [**get_audit_logs**](https://open.teambition.com/docs/apis/6620e7e6912d20d3b551cda8) | **GET** /audit-log/list | 获取企业审计日志
*OrgApi* | [**get_ding_corp_id**](https://open.teambition.com/docs/apis/66792847912d20d3b5161000) | **GET** /idmap/dingtalk/getCorpId | 查询企业绑定的钉钉 CorpId
*OrgApi* | [**get_ding_user_id_by_tb_user_id**](https://open.teambition.com/docs/apis/66792847912d20d3b5160f7d) | **GET** /idmap/dingtalk/getDingUserId | Teambition userId 查询钉钉 userId
*OrgApi* | [**get_org_info**](https://open.teambition.com/docs/apis/6321c6ce912d20d3b5a488f4) | **GET** /org/info | 获取企业信息
*OrgApi* | [**get_tb_user_id_by_ding_user_id**](https://open.teambition.com/docs/apis/66792847912d20d3b5160f10) | **GET** /idmap/dingtalk/getTbUserId | 钉钉 userId 查询 Teambition userId
*OrgApi* | [**list_license_allocations**](https://open.teambition.com/docs/apis/6364d27b912d20d3b5f654a5) | **GET** /seat/member/allocated | 获取License名额分配列表
*ProgramApi* | [**add_program_members_v3**](https://open.teambition.com/docs/apis/66693d96912d20d3b5ee560b) | **POST** /v3/program/{programId}/member/create | 批量添加成员到项目集
*ProgramApi* | [**add_program_projects_v3**](https://open.teambition.com/docs/apis/64e810ff912d20d3b58fa74a) | **POST** /v3/program/{programId}/project/create | 批量添加项目到项目集
*ProgramApi* | [**create_program_status_custom_field_v3**](https://open.teambition.com/docs/apis/66e00a72912d20d3b5a1572b) | **POST** /v3/program/{programId}/status/customfield/create | 更新项目集概览自定义字段值
*ProgramApi* | [**create_program_status_v3**](https://open.teambition.com/docs/apis/66e00a72912d20d3b5a15688) | **POST** /v3/program/{programId}/status/create | 创建项目集状态
*ProgramApi* | [**create_program_v3**](https://open.teambition.com/docs/apis/64e810ff912d20d3b58fa614) | **POST** /v3/program/create | 创建项目集
*ProgramApi* | [**delete_program_status_custom_field_v3**](https://open.teambition.com/docs/apis/66e00a72912d20d3b5a1578a) | **POST** /v3/program/{programId}/status/customfield/delete | 删除项目集概览自定义字段
*ProgramApi* | [**delete_program_status_v3**](https://open.teambition.com/docs/apis/66e00a72912d20d3b5a15875) | **POST** /v3/program/{programId}/status/delete | 删除项目集状态
*ProgramApi* | [**delete_program_v3**](https://open.teambition.com/docs/apis/64e810ff912d20d3b58fa695) | **POST** /v3/program/{programId}/delete | 删除项目集
*ProgramApi* | [**get_programs_v3**](https://open.teambition.com/docs/apis/6501ad17912d20d3b5086630) | **GET** /v3/program/query | 查询项目集
*ProgramApi* | [**list_program_members_v3**](https://open.teambition.com/docs/apis/66693d96912d20d3b5ee5737) | **GET** /v3/program/{programId}/member | 查询项目集内成员
*ProgramApi* | [**list_program_projects_v3**](https://open.teambition.com/docs/apis/64e810ff912d20d3b58fa85c) | **GET** /v3/program/{programId}/projects | 查询项目集内项目
*ProgramApi* | [**list_program_status_custom_fields_v3**](https://open.teambition.com/docs/apis/66e00a72912d20d3b5a157f5) | **GET** /v3/program/{programId}/status/customfield/list | 查询项目集概览自定义字段列表
*ProgramApi* | [**list_program_statuses_v3**](https://open.teambition.com/docs/apis/66e00a73912d20d3b5a158dd) | **GET** /v3/program/{programId}/status/list | 查询项目集状态和状态历史
*ProgramApi* | [**post_v3_program_update**](https://open.teambition.com/docs/apis/68d8933e92244c2db32beebe) | **POST** /v3/program/{programId}/update | 更新项目集信息
*ProgramApi* | [**remove_program_members_v3**](https://open.teambition.com/docs/apis/66693d96912d20d3b5ee56af) | **POST** /v3/program/{programId}/member/delete | 批量删除项目集内的成员
*ProgramApi* | [**remove_program_project_v3**](https://open.teambition.com/docs/apis/64e810ff912d20d3b58fa7d3) | **POST** /v3/program/{programId}/project/{projectId}/delete | 删除项目集内的项目
*ProjectApi* | [**add_project_group_member_v3**](https://open.teambition.com/docs/apis/6646e45a912d20d3b576c2f0) | **POST** /v3/project-tag/{projectTagId}/member/create | 创建项目分组成员
*ProjectApi* | [**add_project_members_v3**](https://open.teambition.com/docs/apis/6363bcfa912d20d3b56faf07) | **POST** /v3/project/{projectId}/member/create-v2 | 创建项目成员 v2
*ProjectApi* | [**archive_project_v3**](https://open.teambition.com/docs/apis/6321c6d0912d20d3b5a496ed) | **POST** /v3/project/{projectId}/archive | 项目放入回收站
*ProjectApi* | [**assign_member_role_v3**](https://open.teambition.com/docs/apis/6321c6d0912d20d3b5a49942) | **POST** /v3/project/{projectId}/member/role/assign | 修改项目成员的角色
*ProjectApi* | [**batch_get_project_custom_filed_by_instance_ids_v3**](https://open.teambition.com/docs/apis/6321c6d0912d20d3b5a497b9) | **GET** /v3/project/{projectId}/customfield/get-by-instance | 批量根据instanceId查询字段
*ProjectApi* | [**complete_sprint_v3**](https://open.teambition.com/docs/apis/63a08188912d20d3b56b9231) | **PUT** /v3/project/{projectId}/sprint/{sprintId}/complete | 完成迭代
*ProjectApi* | [**copy_project_async_v3**](https://open.teambition.com/docs/apis/64e810ff912d20d3b58fa8bc) | **POST** /v3/project/{projectId}/copy-async | 异步复制项目
*ProjectApi* | [**copy_project_v3**](https://open.teambition.com/docs/apis/6321c6d0912d20d3b5a49724) | **POST** /v3/project/{projectId}/copy | 复制项目
*ProjectApi* | [**count_project_tasks_v3**](https://open.teambition.com/docs/apis/6646e45a912d20d3b576c01a) | **GET** /v3/project/{projectId}/task/count | 计数项目任务
*ProjectApi* | [**create_bug_group**](https://open.teambition.com/docs/apis/682c1944912d20d3b5a29c8c) | **POST** /v3/project/{projectId}/bug/commongroup/create | 创建缺陷分类
*ProjectApi* | [**create_org_project_role_v3**](https://open.teambition.com/docs/apis/6321c6d1912d20d3b5a4a356) | **POST** /v3/project-role/create | 创建企业后台项目角色
*ProjectApi* | [**create_project_from_template_v3**](https://open.teambition.com/docs/apis/6321c6d0912d20d3b5a49753) | **POST** /v3/project/create-from-template | 从模板创建项目
*ProjectApi* | [**create_project_group_v3**](https://open.teambition.com/docs/apis/6363b54f912d20d3b567d83b) | **POST** /v3/project-tag/create | 创建项目分组
*ProjectApi* | [**create_project_link_v3**](https://open.teambition.com/docs/apis/6321c6d0912d20d3b5a499a5) | **POST** /v3/project/{projectId}/objectlinks | 创建项目关联
*ProjectApi* | [**create_project_member_v3**](https://open.teambition.com/docs/apis/6321c6d0912d20d3b5a498c0) | **POST** /v3/project/{projectId}/member/create | 创建项目成员(弃用)
*ProjectApi* | [**create_project_role_v3**](https://open.teambition.com/docs/apis/6321c6d1912d20d3b5a49b28) | **POST** /v3/project/{projectId}/role/create | 创建项目角色
*ProjectApi* | [**create_project_status_v3**](https://open.teambition.com/docs/apis/63e2387a912d20d3b5d3fe38) | **POST** /v3/project/{projectId}/status/create | 创建项目状态
*ProjectApi* | [**create_project_tag_v3**](https://open.teambition.com/docs/apis/63e2386b912d20d3b5d3ef64) | **POST** /v3/project/{projectId}/tag/create | 创建项目标签
*ProjectApi* | [**create_project_template_v3**](https://open.teambition.com/docs/apis/66431ec5912d20d3b5436e4c) | **POST** /v3/project-template/create | 创建项目模版
*ProjectApi* | [**create_project_v3**](https://open.teambition.com/docs/apis/6321c6d0912d20d3b5a49780) | **POST** /v3/project/create | 创建项目
*ProjectApi* | [**create_role_from_template_v3**](https://open.teambition.com/docs/apis/6321c6d0912d20d3b5a49ae8) | **POST** /v3/project/{projectId}/role/create-by-project-role | 引入企业后台项目角色到项目
*ProjectApi* | [**create_sprint_v3**](https://open.teambition.com/docs/apis/63a08188912d20d3b56b92b9) | **POST** /v3/project/{projectId}/sprint/create | 创建迭代
*ProjectApi* | [**create_status_custom_field_v3**](https://open.teambition.com/docs/apis/6321c6d1912d20d3b5a49d3f) | **POST** /v3/project/{projectId}/status/customfield/create | 更新项目概览自定义字段值
*ProjectApi* | [**create_story_group**](https://open.teambition.com/docs/apis/682c1948912d20d3b5a2b50e) | **POST** /v3/project/{projectId}/story/commongroup/create | 创建需求分类
*ProjectApi* | [**create_task_group_v3**](https://open.teambition.com/docs/apis/64264d40912d20d3b58848b3) | **POST** /v3/project/{projectId}/tasklist/create | 创建任务分组
*ProjectApi* | [**create_task_stage_v3**](https://open.teambition.com/docs/apis/64264d40912d20d3b5884608) | **POST** /v3/project/{projectId}/stage/create | 创建任务列表
*ProjectApi* | [**create_taskflow_status_v3**](https://open.teambition.com/docs/apis/6321c6d1912d20d3b5a4a003) | **POST** /v3/project/{projectId}/taskflowstatus/create | 创建项目工作流状态
*ProjectApi* | [**create_taskflow_v3**](https://open.teambition.com/docs/apis/6321c6d1912d20d3b5a49ef9) | **POST** /v3/project/{projectId}/taskflow/create | 创建项目工作流
*ProjectApi* | [**create_test_plan**](https://open.teambition.com/docs/apis/6321c6d2912d20d3b5a4a92e) | **POST** /v3/project/{projectId}/testplan/create | 创建测试计划
*ProjectApi* | [**create_test_plan_group**](https://open.teambition.com/docs/apis/6321c6d2912d20d3b5a4a886) | **POST** /v3/project/{projectId}/testplan/{testplanId}/commongroup/create | 创建测试计划分组
*ProjectApi* | [**delete_org_project_role_v3**](https://open.teambition.com/docs/apis/6321c6d1912d20d3b5a4a399) | **POST** /v3/project-role/{roleId}/delete | 删除企业后台项目角色
*ProjectApi* | [**delete_project_group_v3**](https://open.teambition.com/docs/apis/6363bcfb912d20d3b56fb3b4) | **DELETE** /v3/project-tag/{projectTagId} | 删除项目分组
*ProjectApi* | [**delete_project_link_v3**](https://open.teambition.com/docs/apis/6321c6d0912d20d3b5a499df) | **DELETE** /v3/project/{projectId}/objectlinks/{objectlinkId} | 删除项目关联
*ProjectApi* | [**delete_project_member_v3**](https://open.teambition.com/docs/apis/63e23a3e912d20d3b5d599a8) | **POST** /v3/project/{projectId}/member/delete | 删除项目成员
*ProjectApi* | [**delete_project_role_v3**](https://open.teambition.com/docs/apis/6321c6d1912d20d3b5a49b61) | **POST** /v3/project/{projectId}/role/{roleId}/delete | 移除项目角色
*ProjectApi* | [**delete_project_template_v3**](https://open.teambition.com/docs/apis/6643341a912d20d3b58ebb5e) | **DELETE** /v3/project-template/{templateId} | 删除项目模版
*ProjectApi* | [**delete_project_v3**](https://open.teambition.com/docs/apis/66e00a73912d20d3b5a1593b) | **POST** /v3/project/{projectId}/delete | 删除项目
*ProjectApi* | [**delete_sprint_v3**](https://open.teambition.com/docs/apis/63a08188912d20d3b56b9340) | **POST** /v3/project/{projectId}/sprint/{sprintId}/delete | 删除迭代
*ProjectApi* | [**delete_status_custom_field_v3**](https://open.teambition.com/docs/apis/6321c6d1912d20d3b5a49d6f) | **POST** /v3/project/{projectId}/status/customfield/{customfieldId}/delete | 删除项目概览自定义字段(弃用)
*ProjectApi* | [**delete_task_flow_status_v3**](https://open.teambition.com/docs/apis/6437eaa1912d20d3b5685875) | **POST** /v3/project/{projectId}/taskflowstatus/{tfsId}/delete | 删除项目工作流状态
*ProjectApi* | [**delete_taskflow_v3**](https://open.teambition.com/docs/apis/6321c6d1912d20d3b5a49f36) | **POST** /v3/project/{projectId}/taskflow/{taskflowId}/delete | 删除项目工作流
*ProjectApi* | [**get_async_job_result_v3**](https://open.teambition.com/docs/apis/6501ad12912d20d3b50846fc) | **GET** /v3/async-job/list | 获取异步 job 执行结果
*ProjectApi* | [**get_member_roles_v3**](https://open.teambition.com/docs/apis/6363bcfb912d20d3b56fafcb) | **GET** /v3/project/{projectId}/member-role | 获取项目成员角色（包含权限穿透角色）
*ProjectApi* | [**get_project_links_v3**](https://open.teambition.com/docs/apis/6321c6d0912d20d3b5a4996f) | **GET** /v3/project/{projectId}/objectlinks | 获取项目关联列表
*ProjectApi* | [**get_project_org_chart**](https://open.teambition.com/docs/apis/6808506d912d20d3b5bfe3a5) | **GET** /v3/project/{projectId}/preference/project-team | 获取项目组织架构图
*ProjectApi* | [**get_project_program**](https://open.teambition.com/docs/apis/67d0f72e912d20d3b5f09e35) | **GET** /v3/project/{projectId}/program/query | 查询项目所属项目集id
*ProjectApi* | [**get_project_table_custom_field**](https://open.teambition.com/docs/apis/682c18da912d20d3b5a16e8c) | **GET** /v3/project/{projectId}/customfield/table | 获取项目的表格自定义字段
*ProjectApi* | [**get_project_tags_v3**](https://open.teambition.com/docs/apis/6321c6d0912d20d3b5a49a2e) | **GET** /v3/project/{projectId}/project-tag | 查看项目的项目分组
*ProjectApi* | [**get_scenario_fields_v3**](https://open.teambition.com/docs/apis/6321c6d1912d20d3b5a49cc4) | **GET** /v3/project/{projectId}/scenariofieldconfig/search | 获取项目任务类型
*ProjectApi* | [**get_test_case_group_mappings**](https://open.teambition.com/docs/apis/6321c6d1912d20d3b5a4a1b6) | **GET** /v3/project/{projectId}/testcase/commongroup-mapping | 批量获取测试用例与归属分组的对应关系
*ProjectApi* | [**install_project_app_v3**](https://open.teambition.com/docs/apis/6321c6d0912d20d3b5a49662) | **POST** /v3/project/{projectId}/application/{appId}/create | 安装项目应用
*ProjectApi* | [**list_bug_groups**](https://open.teambition.com/docs/apis/66b4ae32912d20d3b5840871) | **GET** /v3/project/{projectId}/bug/commongroup | 获取缺陷分类列表
*ProjectApi* | [**list_org_project_roles_v3**](https://open.teambition.com/docs/apis/6321c6d1912d20d3b5a4a3d2) | **GET** /v3/project-role/list | 获取企业后台项目角色
*ProjectApi* | [**list_priorities_v3**](https://open.teambition.com/docs/apis/6321c6d0912d20d3b5a4961c) | **GET** /v3/project/priority/list | 查询企业优先级
*ProjectApi* | [**list_project_apps_v3**](https://open.teambition.com/docs/apis/6321c6d0912d20d3b5a496c1) | **GET** /v3/project/{projectId}/application/list | 查询项目应用列表
*ProjectApi* | [**list_project_group_members_v3**](https://open.teambition.com/docs/apis/6646e45a912d20d3b576c3fd) | **GET** /v3/project-tag/{projectTagId}/member/list | 获取项目分组成员列表
*ProjectApi* | [**list_project_members_v3**](https://open.teambition.com/docs/apis/6321c6d0912d20d3b5a49906) | **GET** /v3/project/{projectId}/member | 获取项目成员列表
*ProjectApi* | [**list_project_reminders_v3**](https://open.teambition.com/docs/apis/63292c59912d20d3b5da9e3c) | **GET** /v3/project/{projectId}/reminder/list | 获取项目「默认任务提醒」列表
*ProjectApi* | [**list_project_roles_v3**](https://open.teambition.com/docs/apis/6321c6d1912d20d3b5a49b8f) | **GET** /v3/project/{projectId}/role | 获取项目角色列表
*ProjectApi* | [**list_project_statuses_v3**](https://open.teambition.com/docs/apis/6321c6d1912d20d3b5a49dd1) | **GET** /v3/project/{projectId}/status/list | 查询项目状态和状态历史
*ProjectApi* | [**list_starred_projects**](https://open.teambition.com/docs/apis/66e00a73912d20d3b5a15a91) | **GET** /v3/project-star/query | 查询用户星标项目
*ProjectApi* | [**list_status_custom_fields_v3**](https://open.teambition.com/docs/apis/6321c6d1912d20d3b5a49d9d) | **GET** /v3/project/{projectId}/status/customfield/list | 查询项目概览自定义字段列表
*ProjectApi* | [**list_status_executors_v3**](https://open.teambition.com/docs/apis/6363bcfb912d20d3b56fb176) | **GET** /v3/project/{projectId}/taskflowstatus/{tfsId}/executor/list | 列出项目工作流状态流转执行角色列表
*ProjectApi* | [**list_status_field_groups_v3**](https://open.teambition.com/docs/apis/66e00a73912d20d3b5a15b19) | **GET** /v3/project/{projectId}/status/field-group/list | 查询项目概览字段分组列表
*ProjectApi* | [**list_status_validators_v3**](https://open.teambition.com/docs/apis/6363bcfb912d20d3b56fb20e) | **GET** /v3/project/{projectId}/taskflowstatus/{tfsId}/validator/list | 列出项目工作流状态流转校验列表
*ProjectApi* | [**list_story_groups_v3**](https://open.teambition.com/docs/apis/6360900d912d20d3b5bb02a6) | **GET** /v3/project/{projectId}/story/commongroup | 获取需求分类列表
*ProjectApi* | [**list_test_plan_groups**](https://open.teambition.com/docs/apis/6321c6d2912d20d3b5a4a8f1) | **GET** /v3/project/{projectId}/testplan/{testplanId}/commongroup | 获取测试计划分组列表
*ProjectApi* | [**list_test_plans**](https://open.teambition.com/docs/apis/6321c6d2912d20d3b5a4a996) | **GET** /v3/project/{projectId}/testplan | 获取测试计划
*ProjectApi* | [**list_user_projects_v3**](https://open.teambition.com/docs/apis/6321c912912d20d3b5a6beb7) | **GET** /v3/project/user-joined | 获取用户参与项目
*ProjectApi* | [**move_task_flow_status_v3**](https://open.teambition.com/docs/apis/6437eaa1912d20d3b5685947) | **PUT** /v3/project/{projectId}/taskflowstatus/{tfsId}/move | 更新项目工作流状态位置
*ProjectApi* | [**query_group_projects**](https://open.teambition.com/docs/apis/66600ca7912d20d3b57431b0) | **GET** /v3/project-tag/{projectTagId}/project/query | 根据项目分组 ID 查询项目
*ProjectApi* | [**query_project_groups_v3**](https://open.teambition.com/docs/apis/6321c6d1912d20d3b5a4a2c7) | **GET** /v3/project-tag/query | 查询项目分组
*ProjectApi* | [**query_projects_v3**](https://open.teambition.com/docs/apis/6321c6d0912d20d3b5a49aa7) | **GET** /v3/project/query | 查询项目
*ProjectApi* | [**query_test_plan_groups**](https://open.teambition.com/docs/apis/6321c6d2912d20d3b5a4a8bf) | **GET** /v3/project/{projectId}/commongroup/query | 查询测试计划分组
*ProjectApi* | [**query_test_plans**](https://open.teambition.com/docs/apis/6321c6d2912d20d3b5a4a96a) | **GET** /v3/project/{projectId}/testplan/query | 查询测试计划
*ProjectApi* | [**remove_project_group_member_v3**](https://open.teambition.com/docs/apis/664ffdf1912d20d3b5897a22) | **POST** /v3/project-tag/{projectTagId}/member/delete | 删除项目分组成员
*ProjectApi* | [**remove_status_custom_field_v3**](https://open.teambition.com/docs/apis/637f7783912d20d3b5886bf1) | **POST** /v3/project/{projectId}/status/customfield/delete | 删除项目概览自定义字段
*ProjectApi* | [**restart_sprint_v3**](https://open.teambition.com/docs/apis/63a08188912d20d3b56b94d3) | **PUT** /v3/project/{projectId}/sprint/{sprintId}/restart | 重新开始迭代
*ProjectApi* | [**restore_project_v3**](https://open.teambition.com/docs/apis/6321c6d1912d20d3b5a49e13) | **POST** /v3/project/{projectId}/suspend-restore | 恢复归档项目
*ProjectApi* | [**search_org_task_flow_statuses_v3**](https://open.teambition.com/docs/apis/6593c8ee912d20d3b5cd6c75) | **GET** /v3/tfs/search | 搜索企业工作流状态
*ProjectApi* | [**search_project_custom_fileds_v3**](https://open.teambition.com/docs/apis/6321c6d0912d20d3b5a497f6) | **GET** /v3/project/{projectId}/customfield/search | 搜索项目自定义字段
*ProjectApi* | [**search_project_tags_v3**](https://open.teambition.com/docs/apis/6321c6d1912d20d3b5a49e83) | **GET** /v3/project/{projectId}/tag/search | 搜索项目标签
*ProjectApi* | [**search_project_tasks_v3**](https://open.teambition.com/docs/apis/6321c6d1912d20d3b5a49ec1) | **GET** /v3/project/{projectId}/task/query | 查询项目任务
*ProjectApi* | [**search_project_templates_v3**](https://open.teambition.com/docs/apis/6321c6d1912d20d3b5a4a30f) | **GET** /v3/project-template/search | 搜索企业项目模板
*ProjectApi* | [**search_projects_tql**](https://open.teambition.com/docs/apis/6728570f912d20d3b53ed2ea) | **GET** /project/search | 通过TQL搜索项目
*ProjectApi* | [**search_sprints_v3**](https://open.teambition.com/docs/apis/6397f1dc912d20d3b572dc9d) | **GET** /v3/project/{projectId}/sprint/search | 迭代搜索
*ProjectApi* | [**search_stages_v3**](https://open.teambition.com/docs/apis/6363bcfb912d20d3b56fb13f) | **GET** /v3/project/{projectId}/stage/search | 搜索任务列表
*ProjectApi* | [**search_task_groups_v3**](https://open.teambition.com/docs/apis/6321c6d1912d20d3b5a4a17d) | **GET** /v3/project/{projectId}/tasklist/search | 搜索任务分组
*ProjectApi* | [**search_taskflow_nodes**](https://open.teambition.com/docs/apis/682c1944912d20d3b5a299b2) | **GET** /v3/project/{projectId}/taskflow/node/search | 搜索项目工作流节点
*ProjectApi* | [**search_taskflow_statuses_v3**](https://open.teambition.com/docs/apis/6321c6d1912d20d3b5a4a142) | **GET** /v3/project/{projectId}/taskflowstatus/search | 搜索项目工作流状态
*ProjectApi* | [**search_taskflows_v3**](https://open.teambition.com/docs/apis/6321c6d1912d20d3b5a49fc3) | **GET** /v3/project/{projectId}/taskflow/search | 搜索项目工作流
*ProjectApi* | [**star_project**](https://open.teambition.com/docs/apis/66e00a73912d20d3b5a159e2) | **POST** /v3/project-star/create | 创建用户星标项目
*ProjectApi* | [**start_sprint_v3**](https://open.teambition.com/docs/apis/63a08189912d20d3b56b9593) | **PUT** /v3/project/{projectId}/sprint/{sprintId}/start | 开始迭代
*ProjectApi* | [**suspend_project_v3**](https://open.teambition.com/docs/apis/6321c6d1912d20d3b5a49e41) | **POST** /v3/project/{projectId}/suspend | 归档项目
*ProjectApi* | [**uninstall_project_app_v3**](https://open.teambition.com/docs/apis/6321c6d0912d20d3b5a49691) | **POST** /v3/project/{projectId}/application/{appId}/delete | 删除项目应用
*ProjectApi* | [**update_org_project_role_v3**](https://open.teambition.com/docs/apis/6321c6d1912d20d3b5a4a40e) | **POST** /v3/project-role/{roleId} | 更新企业后台项目角色
*ProjectApi* | [**update_project_code**](https://open.teambition.com/docs/apis/6808506d912d20d3b5bfe486) | **PUT** /v3/project/{projectId}/unique-id-prefix | 更新项目编号
*ProjectApi* | [**update_project_custom_field_position**](https://open.teambition.com/docs/apis/671f8c7fff36bd665c8084cb) | **PUT** /v3/project/{projectId}/customfieldLink/{customfieldLinkId}/pos | 更新项目概览自定义字段位置
*ProjectApi* | [**update_project_group_member_permission_v3**](https://open.teambition.com/docs/apis/664ffdf1912d20d3b5897b32) | **POST** /v3/project-tag/{projectTagId}/member/permissions/update | 更新项目分组成员权限
*ProjectApi* | [**update_project_group_v3**](https://open.teambition.com/docs/apis/6363bcfb912d20d3b56fb36f) | **PUT** /v3/project-tag/{projectTagId} | 修改项目分组
*ProjectApi* | [**update_project_table_custom_field**](https://open.teambition.com/docs/apis/682c18da912d20d3b5a16eea) | **PUT** /v3/project/{projectId}/customfield/table | 更新项目的表格自定义字段
*ProjectApi* | [**update_project_tags_v3**](https://open.teambition.com/docs/apis/6321c6d0912d20d3b5a49a5c) | **PUT** /v3/project/{projectId}/project-tag | 更新项目的项目分组
*ProjectApi* | [**update_project_template_info_v3**](https://open.teambition.com/docs/apis/66693d97912d20d3b5ee5e9c) | **PUT** /v3/project-template/{projectTemplateId} | 修改项目模板基本信息
*ProjectApi* | [**update_project_v3**](https://open.teambition.com/docs/apis/6321c6d1912d20d3b5a4a287) | **PUT** /v3/project/{projectId} | 更新项目
*ProjectApi* | [**update_role_permissions_v3**](https://open.teambition.com/docs/apis/6321c6d1912d20d3b5a49bca) | **POST** /v3/project/{projectId}/role/{roleId}/permission/update | 修改项目角色的权限项
*ProjectApi* | [**update_sprint_label_v3**](https://open.teambition.com/docs/apis/63a08188912d20d3b56b93a6) | **PUT** /v3/project/{projectId}/sprint/{sprintId}/label/update | 迭代标签更新
*ProjectApi* | [**update_sprint_lock_v3**](https://open.teambition.com/docs/apis/63a08188912d20d3b56b940a) | **PUT** /v3/project/{projectId}/sprint/{sprintId}/lock/update | 迭代锁定
*ProjectApi* | [**update_sprint_payload_v3**](https://open.teambition.com/docs/apis/63a08188912d20d3b56b946d) | **PUT** /v3/project/{projectId}/sprint/{sprintId}/payload/update | 迭代操作限制更新
*ProjectApi* | [**update_sprint_v3**](https://open.teambition.com/docs/apis/63a08189912d20d3b56b95f6) | **PUT** /v3/project/{projectId}/sprint/{sprintId}/update | 迭代更新
*ProjectApi* | [**update_status_custom_field_v3**](https://open.teambition.com/docs/apis/677b650d912d20d3b5330978) | **POST** /v3/project/{projectId}/status/customfield/update | 更新项目概览自定义字段
*ProjectApi* | [**update_status_executors_v3**](https://open.teambition.com/docs/apis/6363bcfb912d20d3b56fb1ac) | **POST** /v3/project/{projectId}/taskflowstatus/{tfsId}/executor/update | 更新项目工作流状态流转角色列表
*ProjectApi* | [**update_status_field_groups_v3**](https://open.teambition.com/docs/apis/66e00a73912d20d3b5a15ba2) | **PUT** /v3/project/{projectId}/status/field-group | 更新项目概览字段分组列表
*ProjectApi* | [**update_status_validators_v3**](https://open.teambition.com/docs/apis/6363bcfb912d20d3b56fb244) | **POST** /v3/project/{projectId}/taskflowstatus/{tfsId}/validator/update | 更新项目工作流状态流转校验列表
*ProjectApi* | [**update_task_flow_reject_status_v3**](https://open.teambition.com/docs/apis/6437eaa1912d20d3b5685a00) | **PUT** /v3/project/{projectId}/taskflowstatus/{tfsId}/rejectstatus | 更新项目工作流状态流转列表
*ProjectApi* | [**update_task_flow_status_name_v3**](https://open.teambition.com/docs/apis/6437eaa1912d20d3b56859a4) | **PUT** /v3/project/{projectId}/taskflowstatus/{tfsId}/name | 更新项目工作流状态名字
*ProjectApi* | [**update_task_flow_status_type_v3**](https://open.teambition.com/docs/apis/6437eaa1912d20d3b56858e6) | **PUT** /v3/project/{projectId}/taskflowstatus/{tfsId}/kind | 更新项目工作流状态
*ProjectApi* | [**update_task_group_title_v3**](https://open.teambition.com/docs/apis/64264d43912d20d3b588593e) | **PUT** /v3/project/{projectId}/tasklist/{tasklistId}/title | 更新任务分组名称
*ProjectApi* | [**update_task_stage_name_v3**](https://open.teambition.com/docs/apis/64264d43912d20d3b588580a) | **PUT** /v3/project/{projectId}/stage/{stageId}/name | 更新任务列表名称
*ProjectApi* | [**update_taskflow_name_v3**](https://open.teambition.com/docs/apis/6321c6d1912d20d3b5a49f80) | **PUT** /v3/project/{projectId}/taskflow/{taskflowId}/name | 更新项目工作流
*ProjectApi* | [**update_test_case_group**](https://open.teambition.com/docs/apis/6321c6d1912d20d3b5a4a1f2) | **POST** /v3/project/{projectId}/testcase/{testcaseId}/commongroup | 更新项目级测试用例分组
*ProjectplanApi* | [**create_plan_approval_v3**](https://open.teambition.com/docs/apis/67f36da38657139bff2bdd65) | **POST** /v3/projectplan/plans/{projectPlanId}/approve | 创建计划审批信息
*ProjectplanApi* | [**create_project_plan_status_setting_v3**](https://open.teambition.com/docs/apis/67dd2f378657139bff29cf9c) | **POST** /v3/projectplan/projects/{projectId}/planCustomStatusSetting | 配置项目级计划自定义状态信息
*ProjectplanApi* | [**delete_v3_projectplan_scenariofield_delete**](https://open.teambition.com/docs/apis/68c2280892244c2db312d350) | **DELETE** /v3/projectplan/{projectPlanId}/scenariofield/{scenariofieldId}/delete | 删除计划字段配置
*ProjectplanApi* | [**delete_v3_projectplan_scenariofields_deletescenariofields**](https://open.teambition.com/docs/apis/68be840192244c2db391a717) | **DELETE** /v3/projectplan/{projectPlanId}/scenariofields/{scenariofieldId}/deleteScenariofields | 删除计划字段配置
*ProjectplanApi* | [**execute_plan_event_v3**](https://open.teambition.com/docs/apis/67f36bbb8657139bff2bd260) | **PUT** /v3/projectplan/plans/{projectPlanId}/execute/{event} | 更改计划状态(发布/变更/取消变更)
*ProjectplanApi* | [**get_plan_status_v3**](https://open.teambition.com/docs/apis/67dd0bd08657139bff298e21) | **GET** /v3/projectplan/plans/{projectPlanId}/status-info | 查询计划状态信息
*ProjectplanApi* | [**get_plan_v3**](https://open.teambition.com/docs/apis/67dab418a30a3554a5fa69a2) | **GET** /v3/projectplan/plans/{projectPlanId}/query | 查询计划
*ProjectplanApi* | [**get_project_plan_status_setting_v3**](https://open.teambition.com/docs/apis/67dd27bc8657139bff29b100) | **GET** /v3/projectplan/projects/{projectId}/planCustomStatusSetting | 获取项目级计划自定义状态配置
*ProjectplanApi* | [**get_v3_projectplan_listscenariofields**](https://open.teambition.com/docs/apis/68be727692244c2db30fb2ab) | **GET** /v3/projectplan/{projectPlanId}/listScenariofields | 查询计划自定义字段
*ProjectplanApi* | [**get_v3_projectplan_listscenariofieldvalues**](https://open.teambition.com/docs/apis/68be729392244c2db3108604) | **GET** /v3/projectplan/{projectPlanId}/listScenariofieldValues | 获取字段值
*ProjectplanApi* | [**get_v3_projectplan_operable_access_policy_list**](https://open.teambition.com/docs/apis/68c8d1bb92244c2db3644e90) | **GET** /v3/projectplan/{projectPlanId}/operable-access-policy/list | 获取当前计划可设置加锁/解锁的动作
*ProjectplanApi* | [**get_v3_projectplan_plans_list**](https://open.teambition.com/docs/apis/68c26bcc92244c2db3fba872) | **GET** /v3/projectplan/plans/{projectId}/list | 查询用户可见的计划列表
*ProjectplanApi* | [**get_v3_projectplan_scenariofield_list**](https://open.teambition.com/docs/apis/68c2287392244c2db315f81a) | **GET** /v3/projectplan/{projectPlanId}/scenariofield/list | 查询计划自定义字段
*ProjectplanApi* | [**get_v3_projectplan_scenariofield_value_list**](https://open.teambition.com/docs/apis/68c2281892244c2db3134763) | **GET** /v3/projectplan/{projectPlanId}/scenariofield/value/list | 获取字段值
*ProjectplanApi* | [**get_v3_projectplan_task_operable_access_policy_list**](https://open.teambition.com/docs/apis/68c8cfba92244c2db3558f77) | **GET** /v3/projectplan/{projectPlanId}/task/{taskId}/operable-access-policy/list | 获取当前计划任务可设置加锁/解锁的动作
*ProjectplanApi* | [**get_v3_projectplan_task_plans_tasks_subtasks**](https://open.teambition.com/docs/apis/68ba4c2292244c2db3c17acf) | **GET** /v3/projectplan-task/plans/{projectPlanId}/tasks/{taskId}/subtasks | 获取计划任务的子任务
*ProjectplanApi* | [**list_plan_member_roles_v3**](https://open.teambition.com/docs/apis/684a3a42912d20d3b5bcea9f) | **GET** /v3/projectplan/{projectPlanId}/members/list | 查询计划成员角色
*ProjectplanApi* | [**list_plan_versions_v3**](https://open.teambition.com/docs/apis/684a341d912d20d3b5aff931) | **GET** /v3/projectplan/{projectPlanId}/version/list | 查询计划版本列表
*ProjectplanApi* | [**list_project_plan_tasks_legacy_v3**](https://open.teambition.com/docs/apis/682d4da6912d20d3b5bc4684) | **GET** /v3/projectplan-task/plans/{projectPlanId}/tasks | 获取计划任务列表
*ProjectplanApi* | [**list_visible_plans_v3**](https://open.teambition.com/docs/apis/682464b6912d20d3b5175b79) | **GET** /v3/projectplan/projects/{projectId}/list | 查询用户可见的计划列表
*ProjectplanApi* | [**post_v3_projectplan_change_rule_update**](https://open.teambition.com/docs/apis/68d23a7392244c2db34a925b) | **POST** /v3/projectplan/{projectPlanId}/change-rule/update | 更新计划发布规则
*ProjectplanApi* | [**post_v3_projectplan_createscenariofields**](https://open.teambition.com/docs/apis/68be782192244c2db339b16a) | **POST** /v3/projectplan/{projectPlanId}/createScenariofields | 关联计划自定义字段
*ProjectplanApi* | [**post_v3_projectplan_project_plans**](https://open.teambition.com/docs/apis/68be726f92244c2db30f7ba7) | **POST** /v3/projectplan/project/{projectId}/plans | 创建计划
*ProjectplanApi* | [**post_v3_projectplan_scenariofield_update**](https://open.teambition.com/docs/apis/68c2281392244c2db3132177) | **POST** /v3/projectplan/{projectPlanId}/scenariofield/update | 关联计划自定义字段
*ProjectplanApi* | [**post_v3_projectplan_task_access_policy_update**](https://open.teambition.com/docs/apis/68c8cfb292244c2db3555244) | **POST** /v3/projectplan/{projectPlanId}/task/{taskId}/access-policy/update | 更新计划任务加锁/解锁动作
*ProjectplanApi* | [**post_v3_projectplan_task_plans_addexisttasks**](https://open.teambition.com/docs/apis/68ba4c2292244c2db3c17b69) | **POST** /v3/projectplan-task/plans/{projectPlanId}/addExistTasks | 将项目任务加入到计划
*ProjectplanApi* | [**post_v3_projectplan_task_plans_tasks**](https://open.teambition.com/docs/apis/68ba4c2392244c2db3c17e08) | **POST** /v3/projectplan-task/plans/{projectPlanId}/tasks | 创建计划任务
*ProjectplanApi* | [**post_v3_projectplan_task_plans_tasks_archive**](https://open.teambition.com/docs/apis/68ba4c2392244c2db3c17f56) | **POST** /v3/projectplan-task/plans/{projectPlanId}/tasks/{taskId}/archive | 删除计划任务
*ProjectplanApi* | [**put_v3_projectplan_scenariofield_value_update**](https://open.teambition.com/docs/apis/68c2282492244c2db313aa44) | **PUT** /v3/projectplan/{projectPlanId}/scenariofield/{scenariofieldId}/value/update | 更新字段值
*ProjectplanApi* | [**put_v3_projectplan_scenariofields_updatescenariofieldvalue**](https://open.teambition.com/docs/apis/68be83fa92244c2db39179e8) | **PUT** /v3/projectplan/{projectPlanId}/scenariofields/{scenariofieldId}/updateScenariofieldValue | 更新字段值
*ProjectplanApi* | [**put_v3_projectplan_task_plans_tasks_executorid**](https://open.teambition.com/docs/apis/68ba4c2392244c2db3c1800c) | **PUT** /v3/projectplan-task/plans/{projectPlanId}/tasks/{taskId}/executorId | 更新计划任务执行者
*ProjectplanApi* | [**search_project_plan_tasks_v3**](https://open.teambition.com/docs/apis/6822be41912d20d3b528f442) | **GET** /v3/project/{projectId}/plan-task/search | 通过TQL搜索项目计划任务
*ProjectplanApi* | [**update_plan_approval_v3**](https://open.teambition.com/docs/apis/67f36f5e8657139bff2be59c) | **PUT** /v3/projectplan/plans/{projectPlanId}/approve | 更新计划审批信息
*ProjectplanApi* | [**update_plan_custom_status_v3**](https://open.teambition.com/docs/apis/67dd2d338657139bff29c843) | **PUT** /v3/projectplan/plans/{projectPlanId}/customStatus | 配置计划自定义状态
*ProjectplanApi* | [**update_plan_member_role_v3**](https://open.teambition.com/docs/apis/67e24a3e38cb5ab7af0b344c) | **POST** /v3/projectplan/plans/{projectPlanId}/members | 修改计划成员角色
*ProjectplanApi* | [**update_project_plan_task_v3**](https://open.teambition.com/docs/apis/683570b6912d20d3b5f3e246) | **PUT** /v3/projectplan-task/plans/{projectPlanId}/tasks/{taskId} | 更新计划任务（标题、开始时间、截止时间）
*ReportApi* | [**sum_project_work_time**](https://open.teambition.com/docs/apis/63a4237d912d20d3b57fbd65) | **POST** /report/project/{projectId}/statistics/worktime/total | 计算项目总工时
*ReportApi* | [**sum_work_time_by_user**](https://open.teambition.com/docs/apis/63a4237d912d20d3b57fbbc4) | **POST** /report/project/{projectId}/statistics/worktime | 按人维度汇总工时
*SeatApi* | [**create_quota_rule**](https://open.teambition.com/docs/apis/649aa48d11b042002ab6f10c) | **POST** /seat/project/allocate | 创建名额分配规则
*SfcApi* | [**create_sfc_v3**](https://open.teambition.com/docs/apis/6321c6d1912d20d3b5a49c04) | **POST** /v3/sfc/create | 创建项目任务类型(提交项目ID), 创建企业任务类型
*SfcApi* | [**delete_sfc_field_v3**](https://open.teambition.com/docs/apis/63c7e586912d20d3b53ceb55) | **POST** /v3/sfc/{sfcId}/sf/delete | 删除项目/企业的任务类型的字段
*SfcApi* | [**delete_sfc_v3**](https://open.teambition.com/docs/apis/63a08188912d20d3b56b90bb) | **POST** /v3/sfc/{sfcId}/delete | 删除项目任务类型(提交项目ID), 删除企业任务类型
*SfcApi* | [**search_org_sfc_v3**](https://open.teambition.com/docs/apis/63ee3ea2912d20d3b543f1ae) | **GET** /v3/scenariofieldconfig/search | 搜索企业任务类型
*SfcApi* | [**update_sfc_field_v3**](https://open.teambition.com/docs/apis/63c7e586912d20d3b53cebc0) | **POST** /v3/sfc/{sfcId}/sf | 创建/修改 项目/企业的任务类型的字段
*SfcApi* | [**update_sfc_taskflow_v3**](https://open.teambition.com/docs/apis/6321c6d1912d20d3b5a49cf7) | **PUT** /v3/sfc/{sfcId}/taskflow | 修改项目下任务类型绑定工作流
*SfcApi* | [**update_sfc_v3**](https://open.teambition.com/docs/apis/6321c6d1912d20d3b5a49c43) | **PUT** /v3/sfc/{sfcId} | 修改项目任务类型(提交项目ID), 修改企业任务类型
*TagApi* | [**create_org_tag_v3**](https://open.teambition.com/docs/apis/63ee3ea2912d20d3b543f21f) | **POST** /v3/tag/create | 创建企业标签
*TagApi* | [**search_org_tags_v3**](https://open.teambition.com/docs/apis/63ee3ea2912d20d3b543f28b) | **GET** /v3/tag/search | 搜索企业标签
*TaskApi* | [**archive_task_v3**](https://open.teambition.com/docs/apis/6321c6d1912d20d3b5a4a43a) | **PUT** /v3/task/{taskId}/archive | 归档任务(移入回收站)
*TaskApi* | [**create_task_comment_v3**](https://open.teambition.com/docs/apis/6321c6d1912d20d3b5a4a469) | **POST** /v3/task/{taskId}/comment | 评论任务
*TaskApi* | [**create_task_dependency_v3**](https://open.teambition.com/docs/apis/65bcb725912d20d3b57a1c76) | **POST** /v3/task/dependency/create | 创建任务依赖
*TaskApi* | [**create_task_link_v3**](https://open.teambition.com/docs/apis/6321c6d2912d20d3b5a4a728) | **POST** /v3/task/{taskId}/objectlinks | 创建任务关联
*TaskApi* | [**create_task_trace_v3**](https://open.teambition.com/docs/apis/63ee3ea3912d20d3b543f315) | **POST** /v3/task/{taskId}/trace/create | 创建任务进展
*TaskApi* | [**create_task_v3**](https://open.teambition.com/docs/apis/6321c6d1912d20d3b5a4a514) | **POST** /v3/task/create | 创建任务
*TaskApi* | [**delete_task_dependency_v3**](https://open.teambition.com/docs/apis/65e5c202912d20d3b50a63ad) | **POST** /v3/task/dependency/{dependencyId}/delete | 删除任务依赖
*TaskApi* | [**delete_task_link_v3**](https://open.teambition.com/docs/apis/6321c6d2912d20d3b5a4a754) | **DELETE** /v3/task/{taskId}/objectlinks/{objectlinkId} | 删除任务关联
*TaskApi* | [**delete_task_v3**](https://open.teambition.com/docs/apis/6321c6d2912d20d3b5a4a5e1) | **POST** /v3/task/{taskId}/delete | 删除任务
*TaskApi* | [**get_task_dependencies_v3**](https://open.teambition.com/docs/apis/63613a18912d20d3b5296e6d) | **GET** /v3/task/dependency | 获取任务依赖
*TaskApi* | [**get_task_links_v3**](https://open.teambition.com/docs/apis/6321c6d2912d20d3b5a4a6fb) | **GET** /v3/task/{taskId}/objectlinks | 获取任务关联列表
*TaskApi* | [**get_task_table_custom_field_v3**](https://open.teambition.com/docs/apis/682c19c9912d20d3b5a477bf) | **GET** /v3/task/{taskId}/customfield/table | 获取任务的表格自定义字段
*TaskApi* | [**get_task_traces_v3**](https://open.teambition.com/docs/apis/6363bcfa912d20d3b56faed0) | **GET** /v3/task/{taskId}/traces | 获取任务进展
*TaskApi* | [**get_template_v2**](https://open.teambition.com/docs/apis/6321c6d4912d20d3b5a4b2e0) | **GET** /v2/template/info | 根据ID获取任务类型信息V2
*TaskApi* | [**list_task_activities_v3**](https://open.teambition.com/docs/apis/6363bcfb912d20d3b56fb3f4) | **GET** /v3/task/{taskId}/activity/list | 列出任务动态
*TaskApi* | [**move_org_task_to_project**](https://open.teambition.com/docs/apis/6823ee2e912d20d3b52ae3da) | **POST** /v3/organization-task/{taskId}/move | 轻任务移动到项目中
*TaskApi* | [**move_task_v3**](https://open.teambition.com/docs/apis/6321c6d2912d20d3b5a4a69f) | **PUT** /v3/task/{taskId}/move | 跨项目移动任务
*TaskApi* | [**put_v3_task_node_complete**](https://open.teambition.com/docs/apis/68b6854a92244c2db3866dcb) | **PUT** /v3/task/{taskId}/node/complete | 完成任务节点
*TaskApi* | [**put_v3_task_node_list**](https://open.teambition.com/docs/apis/68b6854a92244c2db3866eb5) | **GET** /v3/task/{taskId}/node/list | 获取任务节点列表
*TaskApi* | [**put_v3_task_node_rollback**](https://open.teambition.com/docs/apis/68b6854a92244c2db3866f5e) | **PUT** /v3/task/{taskId}/node/rollback | 回滚任务节点
*TaskApi* | [**put_v3_task_node_update**](https://open.teambition.com/docs/apis/68b6854a92244c2db3867000) | **PUT** /v3/task/{taskId}/node/update | 更新任务节点
*TaskApi* | [**query_task_v3**](https://open.teambition.com/docs/apis/6321c6d2912d20d3b5a4a7b8) | **GET** /v3/task/query | 查询任务详情
*TaskApi* | [**render_task_rtf_v3**](https://open.teambition.com/docs/apis/65309201912d20d3b5cf2ab8) | **GET** /v3/task/rtf/render | 任务富文本内容渲染为 html
*TaskApi* | [**restore_task_v3**](https://open.teambition.com/docs/apis/66601201912d20d3b584bcc8) | **POST** /v3/task/{taskId}/restore | 恢复任务(移出回收站)
*TaskApi* | [**search_tasks_by_tql**](https://open.teambition.com/docs/apis/64264d3e912d20d3b5883b0e) | **GET** /all-task/search | 通过TQL搜索自由任务和项目任务ID
*TaskApi* | [**search_tasks_by_tqlv2**](https://open.teambition.com/docs/apis/68672b12912d20d3b52442f2) | **GET** /v2/all-task/search | 通过TQL搜索自由任务和项目任务ID (V2)
*TaskApi* | [**search_user_tasks_v3**](https://open.teambition.com/docs/apis/63ee4160912d20d3b54548a6) | **GET** /v3/usertasks/search | 搜索用户的任务
*TaskApi* | [**update_task_content_v3**](https://open.teambition.com/docs/apis/6321c6d1912d20d3b5a4a4a0) | **PUT** /v3/task/{taskId}/content | 更新任务标题
*TaskApi* | [**update_task_cusom_field_by_instance_v3**](https://open.teambition.com/docs/apis/6321c6d1912d20d3b5a4a545) | **POST** /v3/task/{taskId}/customfield-instance/{instanceId}/update | 根据字段InstanceId更新任务自定义字段值(弃用)
*TaskApi* | [**update_task_cusom_field_v3**](https://open.teambition.com/docs/apis/6321c6d2912d20d3b5a4a579) | **POST** /v3/task/{taskId}/customfield/update | 更新任务自定义字段值
*TaskApi* | [**update_task_custom_field**](https://open.teambition.com/docs/apis/6321c6d4912d20d3b5a4b391) | **POST** /task/customfield/update | 更新任务字段信息
*TaskApi* | [**update_task_custom_field_v2**](https://open.teambition.com/docs/apis/6321c6d2912d20d3b5a4a5a8) | **POST** /v3/task/{taskId}/customfield/{customfieldId}/update | 更新任务自定义字段值(弃用)
*TaskApi* | [**update_task_due_date_v3**](https://open.teambition.com/docs/apis/6321c6d2912d20d3b5a4a613) | **PUT** /v3/task/{taskId}/dueDate | 更新任务截止时间
*TaskApi* | [**update_task_executor_v3**](https://open.teambition.com/docs/apis/6321c6d2912d20d3b5a4a63d) | **PUT** /v3/task/{taskId}/executor | 更新任务执行者
*TaskApi* | [**update_task_lock_v3**](https://open.teambition.com/docs/apis/662213a0912d20d3b50bfd84) | **POST** /v3/task/{taskId}/access-policy/update | 更新任务加锁/解锁动作
*TaskApi* | [**update_task_members_v3**](https://open.teambition.com/docs/apis/6321c6d2912d20d3b5a4a66a) | **PUT** /v3/task/{taskId}/involveMembers | 更新任务参与者
*TaskApi* | [**update_task_note_v3**](https://open.teambition.com/docs/apis/6321c6d2912d20d3b5a4a6ca) | **PUT** /v3/task/{taskId}/note | 更新任务备注
*TaskApi* | [**update_task_parent_v3**](https://open.teambition.com/docs/apis/63a0818a912d20d3b56b9dea) | **PUT** /v3/task/{taskId}/parent | 改变任务的父任务
*TaskApi* | [**update_task_priority_v3**](https://open.teambition.com/docs/apis/6321c6d2912d20d3b5a4a780) | **PUT** /v3/task/{taskId}/priority | 更新任务优先级
*TaskApi* | [**update_task_progress_v3**](https://open.teambition.com/docs/apis/63a0818a912d20d3b56b9d88) | **PUT** /v3/task/{taskId}/progress | 更新任务进度
*TaskApi* | [**update_task_sfc_v3**](https://open.teambition.com/docs/apis/64b0bc0f912d20d3b5178ce9) | **PUT** /v3/task/{taskId}/sfc/update | 更新任务的任务类型
*TaskApi* | [**update_task_sprint_v3**](https://open.teambition.com/docs/apis/63ab255a912d20d3b596c750) | **PUT** /v3/task/{taskId}/sprint | 更新任务迭代
*TaskApi* | [**update_task_stage_v3**](https://open.teambition.com/docs/apis/63a0818a912d20d3b56b9e50) | **PUT** /v3/task/{taskId}/stage/update | 更新任务列表
*TaskApi* | [**update_task_start_date_v3**](https://open.teambition.com/docs/apis/6321c6d2912d20d3b5a4a7ea) | **PUT** /v3/task/{taskId}/startDate | 更新任务开始时间
*TaskApi* | [**update_task_status_v3**](https://open.teambition.com/docs/apis/6321c6d2912d20d3b5a4a844) | **PUT** /v3/task/{taskId}/taskflowstatus | 更新任务状态
*TaskApi* | [**update_task_story_point_v3**](https://open.teambition.com/docs/apis/63a0818a912d20d3b56b9efc) | **PUT** /v3/task/{taskId}/storyPoint | 更新任务StoryPoint
*TaskApi* | [**update_task_table_custom_field_v3**](https://open.teambition.com/docs/apis/682c19c9912d20d3b5a47827) | **PUT** /v3/task/{taskId}/customfield/table | 更新任务的表格自定义字段
*TaskApi* | [**update_task_tags_v3**](https://open.teambition.com/docs/apis/6321c6d2912d20d3b5a4a819) | **PUT** /v3/task/{taskId}/tag | 更新任务标签
*TaskApi* | [**update_task_visibility_v3**](https://open.teambition.com/docs/apis/664c4d76912d20d3b50bde6e) | **POST** /v3/task/{taskId}/visible/update | 更新任务可见性
*TaskflowApi* | [**search_org_task_flows_v3**](https://open.teambition.com/docs/apis/6593c8ee912d20d3b5cd6bc6) | **GET** /v3/taskflow/search | 搜索企业工作流
*TestcaseApi* | [**create_test_case_v3**](https://open.teambition.com/docs/apis/67bbe1a8912d20d3b545c0c6) | **POST** /v3/project/{projectId}/testcase/create | 创建测试用例
*TestcaseApi* | [**get_project_test_hub_v3**](https://open.teambition.com/docs/apis/67bbe1a8912d20d3b545c179) | **GET** /v3/project/{projectId}/testhub | 查询项目用例库
*TestcaseApi* | [**plan_test_case_v3**](https://open.teambition.com/docs/apis/67bbe1a8912d20d3b545c236) | **POST** /v3/project/{projectId}/testplan/{testplanId}/planning | 规划测试用例
*TestcaseApi* | [**query_org_test_hubs_v3**](https://open.teambition.com/docs/apis/67bbe1a8912d20d3b545c2fa) | **GET** /v3/testhub/query | 查询企业用例库列表
*TestcaseApi* | [**query_org_user_cases_v3**](https://open.teambition.com/docs/apis/67bbe1a8912d20d3b545c355) | **GET** /v3/testhub/{testhubId}/usercase/query | 查询企业用例库用例列表V2
*TestcaseApi* | [**query_project_test_hub_cases_v3**](https://open.teambition.com/docs/apis/67bbe1a8912d20d3b545c1d3) | **GET** /v3/project/{projectId}/testhub/{testhubId}/usercase/query | 查询项目用例库用例列表
*TestcaseApi* | [**query_test_cases_v3**](https://open.teambition.com/docs/apis/67bbe1a8912d20d3b545c11e) | **GET** /v3/project/{projectId}/testcase/query | 查询测试用例列表
*TestcaseApi* | [**query_test_groups_v3**](https://open.teambition.com/docs/apis/67bbec67912d20d3b55c8242) | **POST** /v3/group/query | 批量查询用例分组
*TestcaseApi* | [**update_test_case_flow_status_v3**](https://open.teambition.com/docs/apis/67bbe1a8912d20d3b545c29a) | **PUT** /v3/project/{projectId}/testplan/{testplanId}/testcase/{id}/flowStatusId | 更新测试用例状态
*WebhookApi* | [**get_egress_ips**](https://open.teambition.com/docs/apis/63ec5732ccca5b002ad4052a) | **GET** /webhook/ips | 获取webhook出口IP列表
*WebhookApi* | [**restart_webhook_listen**](https://open.teambition.com/docs/apis/65a0ba1865a529002b97eefa) | **POST** /webhook/v1/apps/{appId}/listen | 消费者服务启动并开始监听上报
*WorktimeApi* | [**aggregate_user_plan_time**](https://open.teambition.com/docs/apis/6321c6cf912d20d3b5a4901c) | **POST** /plantime/aggregation/datesUsers | 获取一定时间内订阅的指定用户的计划工时聚合数
*WorktimeApi* | [**aggregate_user_work_time**](https://open.teambition.com/docs/apis/6321c6cf912d20d3b5a49110) | **POST** /worktime/aggregation/datesUsers | 获取一定时间内订阅的指定用户的实际工时聚合数据
*WorktimeApi* | [**create_plan_time**](https://open.teambition.com/docs/apis/6321c6cf912d20d3b5a48f2c) | **POST** /plantime/create | 创建计划工时
*WorktimeApi* | [**create_work_time**](https://open.teambition.com/docs/apis/6321c6cf912d20d3b5a49058) | **POST** /worktime/create | 创建实际工时
*WorktimeApi* | [**create_work_time_approval**](https://open.teambition.com/docs/apis/64337954e66e7e002b322169) | **POST** /worktime/approve/submit | 创建实际工时审批对象
*WorktimeApi* | [**delete_plan_time**](https://open.teambition.com/docs/apis/640d7cfa7b2cae002b71a567) | **DELETE** /plantime/{plantimeId} | 删除计划工时单条记录
*WorktimeApi* | [**delete_work_time**](https://open.teambition.com/docs/apis/6405ce05b07df7002be7613d) | **DELETE** /worktime/{worktimeId} | 删除实际工时单条记录
*WorktimeApi* | [**get_plan_time_detail**](https://open.teambition.com/docs/apis/6321c6cf912d20d3b5a48f72) | **GET** /plantime/{plantimeId} | 获取单个计划工时详情
*WorktimeApi* | [**get_work_time_detail**](https://open.teambition.com/docs/apis/6321c6cf912d20d3b5a49082) | **GET** /worktime/{worktimeId} | 获取单个实际工时详情
*WorktimeApi* | [**list_plan_times**](https://open.teambition.com/docs/apis/6376eefa912d20d3b59cde89) | **GET** /plantime/query | 获取用户所有计划工时详情数据
*WorktimeApi* | [**list_task_plan_times**](https://open.teambition.com/docs/apis/6321c6cf912d20d3b5a48fa1) | **GET** /plantime/list/task/{taskId} | 获取单个任务的计划工时列表
*WorktimeApi* | [**list_task_work_times**](https://open.teambition.com/docs/apis/6321c6cf912d20d3b5a490b3) | **GET** /worktime/list/task/{taskId} | 获取单个任务的实际工时列表
*WorktimeApi* | [**list_work_times**](https://open.teambition.com/docs/apis/6376eefa912d20d3b59cdeee) | **GET** /worktime/query | 获取用户所有实际工时详情数据
*WorktimeApi* | [**sum_task_plan_time**](https://open.teambition.com/docs/apis/6321c6cf912d20d3b5a48fd3) | **GET** /plantime/aggregation/task/{taskId} | 获取单个任务的计划工时总和
*WorktimeApi* | [**sum_task_work_time**](https://open.teambition.com/docs/apis/6321c6cf912d20d3b5a490e1) | **GET** /worktime/aggregation/task/{taskId} | 获取单个任务的实际工时总和
*WorktimeApi* | [**update_plan_time**](https://open.teambition.com/docs/apis/640593c1bccdde0036d568f9) | **PUT** /plantime/{plantimeId} | 更新计划工时单条记录
*WorktimeApi* | [**update_work_time**](https://open.teambition.com/docs/apis/640594b7b07df7002be69f92) | **PUT** /worktime/{worktimeId} | 更新实际工时单条记录
*WorktimeApi* | [**update_work_time_approval**](https://open.teambition.com/docs/apis/6433c0d2e66e7e002b32b7d3) | **PUT** /worktime/approve/{openId} | 更新工时审批对象
*WorktimeApi* | [**update_work_time_limit**](https://open.teambition.com/docs/apis/66166278912d20d3b5b0af37) | **PUT** /worktime/restriction | 更新工时企业人天的最大填报时间限制

